@@ -4,6 +4,7 @@
 
 from typing import Any, Union
 
+from airbyte_cdk.models import AirbyteMessage
 from airbyte_cdk.sources.concurrent_source.partition_generation_completed_sentinel import (
     PartitionGenerationCompletedSentinel,
 )
@@ -34,5 +35,10 @@ class PartitionCompleteSentinel:
 Typedef representing the items that can be added to the ThreadBasedConcurrentStream
 """
 QueueItem = Union[
-    Record, Partition, PartitionCompleteSentinel, PartitionGenerationCompletedSentinel, Exception
+    Record,
+    Partition,
+    PartitionCompleteSentinel,
+    PartitionGenerationCompletedSentinel,
+    Exception,
+    AirbyteMessage,
 ]
